@@ -32,6 +32,7 @@
 #include "gtype.h"
 #include <gjs/gjs-module.h>
 #include <gjs/compat.h>
+#include <gjs/runtime.h>
 
 #include <util/log.h>
 
@@ -67,10 +68,10 @@ find_field_info(GIObjectInfo *info,
  * Return value is JS_FALSE on OOM/exception.
  */
 static JSBool
-param_get_prop(JSContext *context,
-               JSObject  *obj,
-               jsid       id,
-               jsval     *value_p)
+param_get_prop(JSContext            *context,
+               JSHandleObject        obj,
+               JSHandleId            id,
+               JSMutableHandleValue  value_p)
 {
     JSBool success;
     Param *priv;
@@ -82,10 +83,10 @@ param_get_prop(JSContext *context,
     GITypeInfo *type_info = NULL;
     GIArgument arg;
 
-    if (!gjs_get_string_id(context, id, &name))
+    if (!gjs_get_string_id(context, *id._, &name))
         return JS_TRUE; /* not something we affect, but no error */
 
-    priv = priv_from_js(context, obj);
+    priv = priv_from_js(context, *obj._);
 
     if (priv == NULL) {
         g_free(name);
@@ -100,7 +101,7 @@ param_get_prop(JSContext *context,
 
     if (info == NULL) {
         /* We may have a non-introspectable GParamSpec subclass here. Just return VOID. */
-        *value_p = JSVAL_VOID;
+        *value_p._ = JSVAL_VOID;
         success = JS_TRUE;
         goto out;
     }
@@ -115,7 +116,7 @@ param_get_prop(JSContext *context,
     }
 
     if (field_info == NULL) {
-        *value_p = JSVAL_VOID;
+        *value_p._ = JSVAL_VOID;
         success = JS_TRUE;
         goto out;
     }
@@ -129,7 +130,7 @@ param_get_prop(JSContext *context,
         goto out;
     }
 
-    if (!gjs_value_from_g_argument(context, value_p, type_info, &arg, TRUE))
+    if (!gjs_value_from_g_argument(context, value_p._, type_info, &arg, TRUE))
         goto out;
 
     success = JS_TRUE;
@@ -158,12 +159,12 @@ GJS_NATIVE_CONSTRUCTOR_DECLARE(param)
 }
 
 static void
-param_finalize(JSContext *context,
-               JSObject  *obj)
+param_finalize(JSFreeOp *fop,
+               JSObject *obj)
 {
     Param *priv;
 
-    priv = priv_from_js(context, obj);
+    priv = JS_GetPrivate(obj);
     gjs_debug_lifecycle(GJS_DEBUG_GPARAM,
                         "finalize, obj %p priv %p", obj, priv);
     if (priv == NULL)
@@ -439,8 +440,7 @@ static struct JSClass gjs_param_class = {
     param_finalize,
     NULL,
     NULL,
-    NULL,
-    NULL, NULL, NULL, NULL, NULL
+    NULL, NULL, NULL
 };
 
 static JSPropertySpec gjs_param_proto_props[] = {
@@ -452,31 +452,46 @@ static JSFunctionSpec gjs_param_proto_funcs[] = {
 };
 
 static JSFunctionSpec gjs_param_constructor_funcs[] = {
-    { "_new_internal", (JSNative)param_new_internal, 0, 0 },
+    { "_new_internal", JSOP_WRAPPER((JSNative)param_new_internal), 0, 0 },
     { NULL }
 };
 
-JSObject*
+static JSObject*
 gjs_lookup_param_prototype(JSContext    *context)
 {
-    JSObject *ns;
-    JSObject *proto;
+    JSObject *in_object;
+    JSObject *constructor;
+    jsid gobject_name;
+    jsval value;
 
-    ns = gjs_lookup_namespace_object_by_name(context, "GObject");
+    gobject_name = gjs_intern_string_to_id(context, "GObject");
+    in_object = gjs_lookup_namespace_object_by_name(context, gobject_name);
 
-    if (ns == NULL)
+    if (G_UNLIKELY (!in_object))
         return NULL;
 
-    if (gjs_define_param_class(context, ns, &proto))
-        return proto;
-    else
+    if (!JS_GetProperty(context, in_object, "ParamSpec", &value))
         return NULL;
+
+    if (G_UNLIKELY (!JSVAL_IS_OBJECT(value) || JSVAL_IS_NULL(value)))
+        return NULL;
+
+    constructor = JSVAL_TO_OBJECT(value);
+    g_assert(constructor != NULL);
+
+    if (!gjs_object_get_property_const(context, constructor,
+                                       GJS_STRING_PROTOTYPE, &value))
+        return NULL;
+
+    if (G_UNLIKELY (!JSVAL_IS_OBJECT(value)))
+        return NULL;
+
+    return JSVAL_TO_OBJECT(value);
 }
 
-JSBool
+void
 gjs_define_param_class(JSContext    *context,
-                       JSObject     *in_object,
-                       JSObject    **prototype_p)
+                       JSObject     *in_object)
 {
     const char *constructor_name;
     JSObject *prototype;
@@ -485,30 +500,6 @@ gjs_define_param_class(JSContext    *context,
 
     constructor_name = "ParamSpec";
 
-    gjs_object_get_property(context, in_object, constructor_name, &value);
-    if (!JSVAL_IS_VOID(value)) {
-        if (!JSVAL_IS_OBJECT(value)) {
-            gjs_throw(context, "Existing property '%s' does not look like a constructor",
-                      constructor_name);
-            return JS_FALSE;
-        }
-
-        constructor = JSVAL_TO_OBJECT(value);
-
-        gjs_object_get_property(context, constructor, "prototype", &value);
-        if (!JSVAL_IS_OBJECT(value)) {
-            gjs_throw(context, "prototype property does not appear to exist or has wrong type");
-            return JS_FALSE;
-        } else {
-            if (prototype_p)
-                *prototype_p = JSVAL_TO_OBJECT(value);
-
-            return JS_TRUE;
-        }
-
-        return JS_TRUE;
-    }
-
     if (!gjs_init_class_dynamic(context, in_object,
                                 NULL,
                                 "GObject",
@@ -525,20 +516,15 @@ gjs_define_param_class(JSContext    *context,
                                 gjs_param_constructor_funcs,
                                 &prototype,
                                 &constructor)) {
-        gjs_fatal("Can't init class %s", constructor_name);
+        g_error("Can't init class %s", constructor_name);
     }
 
     value = OBJECT_TO_JSVAL(gjs_gtype_create_gtype_wrapper(context, G_TYPE_PARAM));
     JS_DefineProperty(context, constructor, "$gtype", value,
                       NULL, NULL, JSPROP_PERMANENT);
-    
-    if (prototype_p)
-        *prototype_p = prototype;
 
     gjs_debug(GJS_DEBUG_GPARAM, "Defined class %s prototype is %p class %p in object %p",
-              constructor_name, prototype, JS_GET_CLASS(context, prototype), in_object);
-
-    return JS_TRUE;
+              constructor_name, prototype, JS_GetClass(prototype), in_object);
 }
 
 JSObject*
@@ -561,12 +547,12 @@ gjs_param_from_g_param(JSContext    *context,
     proto = gjs_lookup_param_prototype(context);
 
     obj = JS_NewObjectWithGivenProto(context,
-                                     JS_GET_CLASS(context, proto), proto,
+                                     JS_GetClass(proto), proto,
                                      gjs_get_import_global (context));
 
     GJS_INC_COUNTER(param);
     priv = g_slice_new0(Param);
-    JS_SetPrivate(context, obj, priv);
+    JS_SetPrivate(obj, priv);
     priv->gparam = gparam;
     g_param_spec_ref (gparam);
 
