@@ -33,6 +33,7 @@
 #include "object.h"
 #include <gjs/gjs-module.h>
 #include <gjs/compat.h>
+#include <gjs/runtime.h>
 #include "repo.h"
 #include "proxyutils.h"
 #include "function.h"
@@ -64,8 +65,8 @@ GJS_DEFINE_PRIV_FROM_JS(Union, gjs_union_class)
  */
 static JSBool
 union_new_resolve(JSContext *context,
-                  JSObject  *obj,
-                  jsid       id,
+                  JSObject **obj,
+                  jsid      *id,
                   unsigned   flags,
                   JSObject **objp)
 {
@@ -75,11 +76,11 @@ union_new_resolve(JSContext *context,
 
     *objp = NULL;
 
-    if (!gjs_get_string_id(context, id, &name))
+    if (!gjs_get_string_id(context, *id, &name))
         return JS_TRUE; /* not resolved, but no error */
 
-    priv = priv_from_js(context, obj);
-    gjs_debug_jsprop(GJS_DEBUG_GBOXED, "Resolve prop '%s' hook obj %p priv %p", name, obj, priv);
+    priv = priv_from_js(context, *obj);
+    gjs_debug_jsprop(GJS_DEBUG_GBOXED, "Resolve prop '%s' hook obj %p priv %p", name, *obj, priv);
 
     if (priv == NULL) {
         ret = JS_FALSE; /* wrong class */
@@ -109,7 +110,7 @@ union_new_resolve(JSContext *context,
                       g_base_info_get_namespace( (GIBaseInfo*) priv->info),
                       g_base_info_get_name( (GIBaseInfo*) priv->info));
 
-            union_proto = obj;
+            union_proto = *obj;
 
             if (gjs_define_function(context, union_proto,
                                     g_registered_type_info_get_g_type(priv->info),
@@ -202,13 +203,13 @@ GJS_NATIVE_CONSTRUCTOR_DECLARE(union)
     GJS_INC_COUNTER(boxed);
 
     g_assert(priv_from_js(context, object) == NULL);
-    JS_SetPrivate(context, object, priv);
+    JS_SetPrivate(object, priv);
 
     gjs_debug_lifecycle(GJS_DEBUG_GBOXED,
                         "union constructor, obj %p priv %p",
                         object, priv);
 
-    proto = JS_GetPrototype(context, object);
+    proto = JS_GetPrototype(object);
     gjs_debug_lifecycle(GJS_DEBUG_GBOXED, "union instance __proto__ is %p", proto);
 
     /* If we're the prototype, then post-construct we'll fill in priv->info.
@@ -253,12 +254,12 @@ GJS_NATIVE_CONSTRUCTOR_DECLARE(union)
 }
 
 static void
-union_finalize(JSContext *context,
-               JSObject  *obj)
+union_finalize(JSFreeOp *fop,
+               JSObject *obj)
 {
     Union *priv;
 
-    priv = priv_from_js(context, obj);
+    priv = JS_GetPrivate(obj);
     gjs_debug_lifecycle(GJS_DEBUG_GBOXED,
                         "finalize, obj %p priv %p", obj, priv);
     if (priv == NULL)
@@ -320,8 +321,7 @@ static struct JSClass gjs_union_class = {
     union_finalize,
     NULL,
     NULL,
-    NULL,
-    NULL, NULL, NULL, NULL, NULL
+    NULL, NULL, NULL
 };
 
 static JSPropertySpec gjs_union_proto_props[] = {
@@ -329,66 +329,14 @@ static JSPropertySpec gjs_union_proto_props[] = {
 };
 
 static JSFunctionSpec gjs_union_proto_funcs[] = {
-    { "toString", (JSNative)to_string_func, 0, 0 },
+    { "toString", JSOP_WRAPPER((JSNative)to_string_func), 0, 0 },
     { NULL }
 };
 
-JSObject*
-gjs_lookup_union_constructor(JSContext    *context,
-                             GIUnionInfo  *info)
-{
-    JSObject *ns;
-    JSObject *constructor;
-
-    ns = gjs_lookup_namespace_object(context, (GIBaseInfo*) info);
-
-    if (ns == NULL)
-        return NULL;
-
-    constructor = NULL;
-    if (gjs_define_union_class(context, ns, info,
-                               &constructor, NULL))
-        return constructor;
-    else
-        return NULL;
-}
-
-JSObject*
-gjs_lookup_union_prototype(JSContext    *context,
-                           GIUnionInfo  *info)
-{
-    JSObject *ns;
-    JSObject *proto;
-
-    ns = gjs_lookup_namespace_object(context, (GIBaseInfo*) info);
-
-    if (ns == NULL)
-        return NULL;
-
-    proto = NULL;
-    if (gjs_define_union_class(context, ns, info, NULL, &proto))
-        return proto;
-    else
-        return NULL;
-}
-
-JSClass*
-gjs_lookup_union_class(JSContext    *context,
-                       GIUnionInfo  *info)
-{
-    JSObject *prototype;
-
-    prototype = gjs_lookup_union_prototype(context, info);
-
-    return JS_GET_CLASS(context, prototype);
-}
-
 JSBool
 gjs_define_union_class(JSContext    *context,
                        JSObject     *in_object,
-                       GIUnionInfo  *info,
-                       JSObject    **constructor_p,
-                       JSObject    **prototype_p)
+                       GIUnionInfo  *info)
 {
     const char *constructor_name;
     JSObject *prototype;
@@ -413,29 +361,6 @@ gjs_define_union_class(JSContext    *context,
 
     constructor_name = g_base_info_get_name( (GIBaseInfo*) info);
 
-    if (gjs_object_get_property(context, in_object, constructor_name, &value)) {
-        if (!JSVAL_IS_OBJECT(value)) {
-            gjs_throw(context, "Existing property '%s' does not look like a constructor",
-                         constructor_name);
-            return JS_FALSE;
-        }
-
-        constructor = JSVAL_TO_OBJECT(value);
-
-        gjs_object_get_property(context, constructor, "prototype", &value);
-        if (!JSVAL_IS_OBJECT(value)) {
-            gjs_throw(context, "union %s prototype property does not appear to exist or has wrong type", constructor_name);
-            return JS_FALSE;
-        } else {
-            if (prototype_p)
-                *prototype_p = JSVAL_TO_OBJECT(value);
-            if (constructor_p)
-                *constructor_p = constructor;
-
-            return JS_TRUE;
-        }
-    }
-
     if (!gjs_init_class_dynamic(context, in_object,
                                 NULL,
                                 g_base_info_get_namespace( (GIBaseInfo*) info),
@@ -452,7 +377,7 @@ gjs_define_union_class(JSContext    *context,
                                 NULL,
                                 &prototype,
                                 &constructor)) {
-        gjs_fatal("Can't init class %s", constructor_name);
+        g_error("Can't init class %s", constructor_name);
     }
 
     GJS_INC_COUNTER(boxed);
@@ -460,21 +385,15 @@ gjs_define_union_class(JSContext    *context,
     priv->info = info;
     g_base_info_ref( (GIBaseInfo*) priv->info);
     priv->gtype = gtype;
-    JS_SetPrivate(context, prototype, priv);
+    JS_SetPrivate(prototype, priv);
 
     gjs_debug(GJS_DEBUG_GBOXED, "Defined class %s prototype is %p class %p in object %p",
-              constructor_name, prototype, JS_GET_CLASS(context, prototype), in_object);
+              constructor_name, prototype, JS_GetClass(prototype), in_object);
 
     value = OBJECT_TO_JSVAL(gjs_gtype_create_gtype_wrapper(context, gtype));
     JS_DefineProperty(context, constructor, "$gtype", value,
                       NULL, NULL, JSPROP_PERMANENT);
 
-    if (constructor_p)
-        *constructor_p = constructor;
-
-    if (prototype_p)
-        *prototype_p = prototype;
-
     return JS_TRUE;
 }
 
@@ -504,15 +423,15 @@ gjs_union_from_c_union(JSContext    *context,
                       "Wrapping union %s %p with JSObject",
                       g_base_info_get_name((GIBaseInfo *)info), gboxed);
 
-    proto = gjs_lookup_union_prototype(context, (GIUnionInfo*) info);
+    proto = gjs_lookup_generic_prototype(context, (GIUnionInfo*) info);
 
     obj = JS_NewObjectWithGivenProto(context,
-                                     JS_GET_CLASS(context, proto), proto,
+                                     JS_GetClass(proto), proto,
                                      gjs_get_import_global (context));
 
     GJS_INC_COUNTER(boxed);
     priv = g_slice_new0(Union);
-    JS_SetPrivate(context, obj, priv);
+    JS_SetPrivate(obj, priv);
     priv->info = info;
     g_base_info_ref( (GIBaseInfo *) priv->info);
     priv->gtype = gtype;
