@@ -29,6 +29,7 @@
 #endif
 
 #include <gjs/compat.h>
+#include <gjs/runtime.h>
 #include <glib-object.h>
 
 G_BEGIN_DECLS
@@ -43,6 +44,12 @@ enum {
   GJS_UTIL_ERROR_ARGUMENT_TYPE_MISMATCH
 };
 
+typedef enum {
+    GJS_GLOBAL_SLOT_IMPORTS,
+    GJS_GLOBAL_SLOT_KEEP_ALIVE,
+    GJS_GLOBAL_SLOT_LAST,
+} GjsGlobalSlot;
+
 typedef struct GjsRootedArray GjsRootedArray;
 
 /* Flags that should be set on properties exported from native code modules.
@@ -122,7 +129,7 @@ _GJS_DEFINE_PROTO_FULL(tn, cn, NULL)
 #define _GJS_DEFINE_PROTO_FULL(type_name, cname, ctor) \
 static JSPropertySpec gjs_##cname##_proto_props[]; \
 static JSFunctionSpec gjs_##cname##_proto_funcs[]; \
-static void gjs_##cname##_finalize(JSContext *context, JSObject *obj); \
+static void gjs_##cname##_finalize(JSFreeOp *fop, JSObject *obj); \
 static JSBool gjs_##cname##_new_resolve(JSContext *context, \
                                         JSObject  *obj, \
                                         jsval      id, \
@@ -145,15 +152,16 @@ static struct JSClass gjs_##cname##_class = { \
     gjs_##cname##_finalize, \
     NULL, \
     NULL, \
-    NULL, \
-    NULL, NULL, NULL, NULL, NULL \
+    NULL, NULL, NULL \
 }; \
 jsval gjs_##cname##_create_proto(JSContext *context, JSObject *module, const char *proto_name, JSObject *parent) \
 { \
     jsval rval; \
     JSObject *global = gjs_get_import_global(context); \
-    if (!gjs_object_get_property(context, global, \
-                                 gjs_##cname##_class.name, &rval)) {  \
+    jsid class_name = gjs_intern_string_to_id(context, gjs_##cname##_class.name); \
+    if (!JS_GetPropertyById(context, global, class_name, &rval))                       \
+        return JSVAL_NULL; \
+    if (JSVAL_IS_VOID(rval)) { \
         JSObject *prototype = JS_InitClass(context, global, \
                                  parent, \
                                  &gjs_##cname##_class, \
@@ -168,7 +176,7 @@ jsval gjs_##cname##_create_proto(JSContext *context, JSObject *module, const cha
         } \
         if (!gjs_object_require_property( \
                 context, global, NULL, \
-                gjs_##cname##_class.name, &rval)) { \
+                class_name, &rval)) { \
             return JSVAL_NULL; \
         } \
         if (!JS_DefineProperty(context, module, proto_name, \
@@ -180,19 +188,24 @@ jsval gjs_##cname##_create_proto(JSContext *context, JSObject *module, const cha
 
 gboolean    gjs_init_context_standard        (JSContext       *context);
 
-JSContext*  gjs_runtime_get_context          (JSRuntime       *runtime);
 JSObject*   gjs_get_import_global            (JSContext       *context);
-gboolean    gjs_object_has_property          (JSContext       *context,
-                                              JSObject        *obj,
-                                              const char      *property_name);
-gboolean    gjs_object_get_property          (JSContext       *context,
-                                              JSObject        *obj,
-                                              const char      *property_name,
-                                              jsval           *value_p);
+
+jsval       gjs_get_global_slot              (JSContext       *context,
+                                              GjsGlobalSlot    slot);
+void        gjs_set_global_slot              (JSContext       *context,
+                                              GjsGlobalSlot    slot,
+                                              jsval            value);
+
 gboolean    gjs_object_require_property      (JSContext       *context,
                                               JSObject        *obj,
                                               const char      *obj_description,
-                                              const char      *property_name,
+                                              jsid             property_name,
+                                              jsval           *value_p);
+/* This one is defined in runtime.c, so the compiler can optimize the call
+   to get_const_string() it uses. */
+gboolean    gjs_object_get_property_const    (JSContext       *context,
+                                              JSObject        *obj,
+                                              GjsConstString   property_name,
                                               jsval           *value_p);
 
 JSObject   *gjs_new_object_for_constructor   (JSContext       *context,
@@ -242,14 +255,15 @@ void        gjs_throw_literal                (JSContext       *context,
                                               const char      *string);
 void        gjs_throw_g_error                (JSContext       *context,
                                               GError          *error);
-JSBool      gjs_log_exception                (JSContext       *context,
-                                              char           **message_p);
-JSBool      gjs_log_and_keep_exception       (JSContext       *context,
-                                              char           **message_p);
+
+JSBool      gjs_log_exception                (JSContext       *context);
+JSBool      gjs_log_and_keep_exception       (JSContext       *context);
 JSBool      gjs_move_exception               (JSContext       *src_context,
                                               JSContext       *dest_context);
-void        gjs_log_exception_props          (JSContext       *context,
-                                              jsval            exc);
+JSBool      gjs_log_exception_full           (JSContext       *context,
+                                              jsval            exc,
+                                              JSString        *message);
+
 #ifdef __GJS_UTIL_LOG_H__
 void        gjs_log_object_props             (JSContext       *context,
                                               JSObject        *obj,
@@ -307,7 +321,8 @@ JSBool      gjs_string_get_uint16_data       (JSContext       *context,
 JSBool      gjs_get_string_id                (JSContext       *context,
                                               jsid             id,
                                               char           **name_p);
-
+jsid        gjs_intern_string_to_id          (JSContext       *context,
+                                              const char      *string);
 
 gboolean    gjs_unichar_from_string          (JSContext       *context,
                                               jsval            string,
@@ -362,6 +377,11 @@ gboolean gjs_try_block_gc (void);
 void gjs_block_gc (void);
 void gjs_unblock_gc (void);
 
+JSBool            gjs_context_get_frame_info (JSContext  *context,
+                                              jsval      *stack,
+                                              jsval      *fileName,
+                                              jsval      *lineNumber);
+
 G_END_DECLS
 
 #endif  /* __GJS_JSAPI_UTIL_H__ */
