@@ -265,7 +265,7 @@ _gjs_cairo_context_construct_internal(JSContext *context,
     priv = g_slice_new0(GjsCairoContext);
 
     g_assert(priv_from_js(context, obj) == NULL);
-    JS_SetPrivate(context, obj, priv);
+    JS_SetPrivate(obj, priv);
 
     priv->context = context;
     priv->object = obj;
@@ -305,11 +305,11 @@ GJS_NATIVE_CONSTRUCTOR_DECLARE(cairo_context)
 }
 
 static void
-gjs_cairo_context_finalize(JSContext *context,
-                           JSObject  *obj)
+gjs_cairo_context_finalize(JSFreeOp *fop,
+                           JSObject *obj)
 {
     GjsCairoContext *priv;
-    priv = priv_from_js(context, obj);
+    priv = JS_GetPrivate(obj);
     if (priv == NULL)
         return;
 
@@ -871,104 +871,104 @@ getGroupTarget_func(JSContext *context,
 }
 
 static JSFunctionSpec gjs_cairo_context_proto_funcs[] = {
-    { "$dispose", (JSNative)dispose_func, 0, 0 },
-    { "appendPath", (JSNative)appendPath_func, 0, 0},
-    { "arc", (JSNative)arc_func, 0, 0 },
-    { "arcNegative", (JSNative)arcNegative_func, 0, 0 },
-    { "clip", (JSNative)clip_func, 0, 0 },
-    { "clipExtents", (JSNative)clipExtents_func, 0, 0 },
-    { "clipPreserve", (JSNative)clipPreserve_func, 0, 0 },
-    { "closePath", (JSNative)closePath_func, 0, 0 },
-    { "copyPage", (JSNative)copyPage_func, 0, 0 },
-    { "copyPath", (JSNative)copyPath_func, 0, 0 },
-    { "copyPathFlat", (JSNative)copyPathFlat_func, 0, 0 },
-    { "curveTo", (JSNative)curveTo_func, 0, 0 },
-    { "deviceToUser", (JSNative)deviceToUser_func, 0, 0 },
-    { "deviceToUserDistance", (JSNative)deviceToUserDistance_func, 0, 0 },
-    { "fill", (JSNative)fill_func, 0, 0 },
-    { "fillPreserve", (JSNative)fillPreserve_func, 0, 0 },
-    { "fillExtents", (JSNative)fillExtents_func, 0, 0 },
+    { "$dispose", JSOP_WRAPPER((JSNative)dispose_func), 0, 0 },
+    { "appendPath", JSOP_WRAPPER((JSNative)appendPath_func), 0, 0},
+    { "arc", JSOP_WRAPPER((JSNative)arc_func), 0, 0 },
+    { "arcNegative", JSOP_WRAPPER((JSNative)arcNegative_func), 0, 0 },
+    { "clip", JSOP_WRAPPER((JSNative)clip_func), 0, 0 },
+    { "clipExtents", JSOP_WRAPPER((JSNative)clipExtents_func), 0, 0 },
+    { "clipPreserve", JSOP_WRAPPER((JSNative)clipPreserve_func), 0, 0 },
+    { "closePath", JSOP_WRAPPER((JSNative)closePath_func), 0, 0 },
+    { "copyPage", JSOP_WRAPPER((JSNative)copyPage_func), 0, 0 },
+    { "copyPath", JSOP_WRAPPER((JSNative)copyPath_func), 0, 0 },
+    { "copyPathFlat", JSOP_WRAPPER((JSNative)copyPathFlat_func), 0, 0 },
+    { "curveTo", JSOP_WRAPPER((JSNative)curveTo_func), 0, 0 },
+    { "deviceToUser", JSOP_WRAPPER((JSNative)deviceToUser_func), 0, 0 },
+    { "deviceToUserDistance",JSOP_WRAPPER((JSNative)deviceToUserDistance_func), 0, 0 },
+    { "fill", JSOP_WRAPPER((JSNative)fill_func), 0, 0 },
+    { "fillPreserve", JSOP_WRAPPER((JSNative)fillPreserve_func), 0, 0 },
+    { "fillExtents", JSOP_WRAPPER((JSNative)fillExtents_func), 0, 0 },
     // fontExtents
-    { "getAntialias", (JSNative)getAntialias_func, 0, 0 },
-    { "getCurrentPoint", (JSNative)getCurrentPoint_func, 0, 0 },
+    { "getAntialias", JSOP_WRAPPER((JSNative)getAntialias_func), 0, 0 },
+    { "getCurrentPoint", JSOP_WRAPPER((JSNative)getCurrentPoint_func), 0, 0 },
     // getDash
-    { "getDashCount", (JSNative)getDashCount_func, 0, 0 },
-    { "getFillRule", (JSNative)getFillRule_func, 0, 0 },
+    { "getDashCount", JSOP_WRAPPER((JSNative)getDashCount_func), 0, 0 },
+    { "getFillRule", JSOP_WRAPPER((JSNative)getFillRule_func), 0, 0 },
     // getFontFace
     // getFontMatrix
     // getFontOptions
-    { "getGroupTarget", (JSNative)getGroupTarget_func, 0, 0 },
-    { "getLineCap", (JSNative)getLineCap_func, 0, 0 },
-    { "getLineJoin", (JSNative)getLineJoin_func, 0, 0 },
-    { "getLineWidth", (JSNative)getLineWidth_func, 0, 0 },
+    { "getGroupTarget", JSOP_WRAPPER((JSNative)getGroupTarget_func), 0, 0 },
+    { "getLineCap", JSOP_WRAPPER((JSNative)getLineCap_func), 0, 0 },
+    { "getLineJoin", JSOP_WRAPPER((JSNative)getLineJoin_func), 0, 0 },
+    { "getLineWidth", JSOP_WRAPPER((JSNative)getLineWidth_func), 0, 0 },
     // getMatrix
-    { "getMiterLimit", (JSNative)getMiterLimit_func, 0, 0 },
-    { "getOperator", (JSNative)getOperator_func, 0, 0 },
+    { "getMiterLimit", JSOP_WRAPPER((JSNative)getMiterLimit_func), 0, 0 },
+    { "getOperator", JSOP_WRAPPER((JSNative)getOperator_func), 0, 0 },
     // getScaledFont
-    { "getSource", (JSNative)getSource_func, 0, 0 },
-    { "getTarget", (JSNative)getTarget_func, 0, 0 },
-    { "getTolerance", (JSNative)getTolerance_func, 0, 0 },
+    { "getSource", JSOP_WRAPPER((JSNative)getSource_func), 0, 0 },
+    { "getTarget", JSOP_WRAPPER((JSNative)getTarget_func), 0, 0 },
+    { "getTolerance", JSOP_WRAPPER((JSNative)getTolerance_func), 0, 0 },
     // glyphPath
     // glyphExtents
-    { "hasCurrentPoint", (JSNative)hasCurrentPoint_func, 0, 0 },
-    { "identityMatrix", (JSNative)identityMatrix_func, 0, 0 },
-    { "inFill", (JSNative)inFill_func, 0, 0 },
-    { "inStroke", (JSNative)inStroke_func, 0, 0 },
-    { "lineTo", (JSNative)lineTo_func, 0, 0 },
-    { "mask", (JSNative)mask_func, 0, 0 },
-    { "maskSurface", (JSNative)maskSurface_func, 0, 0 },
-    { "moveTo", (JSNative)moveTo_func, 0, 0 },
-    { "newPath", (JSNative)newPath_func, 0, 0 },
-    { "newSubPath", (JSNative)newSubPath_func, 0, 0 },
-    { "paint", (JSNative)paint_func, 0, 0 },
-    { "paintWithAlpha", (JSNative)paintWithAlpha_func, 0, 0 },
-    { "pathExtents", (JSNative)pathExtents_func, 0, 0 },
-    { "popGroup", (JSNative)popGroup_func, 0, 0 },
-    { "popGroupToSource", (JSNative)popGroupToSource_func, 0, 0 },
-    { "pushGroup", (JSNative)pushGroup_func, 0, 0 },
-    { "pushGroupWithContent", (JSNative)pushGroupWithContent_func, 0, 0 },
-    { "rectangle", (JSNative)rectangle_func, 0, 0 },
-    { "relCurveTo", (JSNative)relCurveTo_func, 0, 0 },
-    { "relLineTo", (JSNative)relLineTo_func, 0, 0 },
-    { "relMoveTo", (JSNative)relMoveTo_func, 0, 0 },
-    { "resetClip", (JSNative)resetClip_func, 0, 0 },
-    { "restore", (JSNative)restore_func, 0, 0 },
-    { "rotate", (JSNative)rotate_func, 0, 0 },
-    { "save", (JSNative)save_func, 0, 0 },
-    { "scale", (JSNative)scale_func, 0, 0 },
-    { "selectFontFace", (JSNative)selectFontFace_func, 0, 0 },
-    { "setAntialias", (JSNative)setAntialias_func, 0, 0 },
-    { "setDash", (JSNative)setDash_func, 0, 0 },
+    { "hasCurrentPoint", JSOP_WRAPPER((JSNative)hasCurrentPoint_func), 0, 0 },
+    { "identityMatrix", JSOP_WRAPPER((JSNative)identityMatrix_func), 0, 0 },
+    { "inFill", JSOP_WRAPPER((JSNative)inFill_func), 0, 0 },
+    { "inStroke", JSOP_WRAPPER((JSNative)inStroke_func), 0, 0 },
+    { "lineTo", JSOP_WRAPPER((JSNative)lineTo_func), 0, 0 },
+    { "mask", JSOP_WRAPPER((JSNative)mask_func), 0, 0 },
+    { "maskSurface", JSOP_WRAPPER((JSNative)maskSurface_func), 0, 0 },
+    { "moveTo", JSOP_WRAPPER((JSNative)moveTo_func), 0, 0 },
+    { "newPath", JSOP_WRAPPER((JSNative)newPath_func), 0, 0 },
+    { "newSubPath", JSOP_WRAPPER((JSNative)newSubPath_func), 0, 0 },
+    { "paint", JSOP_WRAPPER((JSNative)paint_func), 0, 0 },
+    { "paintWithAlpha", JSOP_WRAPPER((JSNative)paintWithAlpha_func), 0, 0 },
+    { "pathExtents", JSOP_WRAPPER((JSNative)pathExtents_func), 0, 0 },
+    { "popGroup", JSOP_WRAPPER((JSNative)popGroup_func), 0, 0 },
+    { "popGroupToSource", JSOP_WRAPPER((JSNative)popGroupToSource_func), 0, 0 },
+    { "pushGroup", JSOP_WRAPPER((JSNative)pushGroup_func), 0, 0 },
+    { "pushGroupWithContent", JSOP_WRAPPER((JSNative)pushGroupWithContent_func), 0, 0 },
+    { "rectangle", JSOP_WRAPPER((JSNative)rectangle_func), 0, 0 },
+    { "relCurveTo", JSOP_WRAPPER((JSNative)relCurveTo_func), 0, 0 },
+    { "relLineTo", JSOP_WRAPPER((JSNative)relLineTo_func), 0, 0 },
+    { "relMoveTo", JSOP_WRAPPER((JSNative)relMoveTo_func), 0, 0 },
+    { "resetClip", JSOP_WRAPPER((JSNative)resetClip_func), 0, 0 },
+    { "restore", JSOP_WRAPPER((JSNative)restore_func), 0, 0 },
+    { "rotate", JSOP_WRAPPER((JSNative)rotate_func), 0, 0 },
+    { "save", JSOP_WRAPPER((JSNative)save_func), 0, 0 },
+    { "scale", JSOP_WRAPPER((JSNative)scale_func), 0, 0 },
+    { "selectFontFace", JSOP_WRAPPER((JSNative)selectFontFace_func), 0, 0 },
+    { "setAntialias", JSOP_WRAPPER((JSNative)setAntialias_func), 0, 0 },
+    { "setDash", JSOP_WRAPPER((JSNative)setDash_func), 0, 0 },
     // setFontFace
     // setFontMatrix
     // setFontOptions
-    { "setFontSize", (JSNative)setFontSize_func, 0, 0 },
-    { "setFillRule", (JSNative)setFillRule_func, 0, 0 },
-    { "setLineCap", (JSNative)setLineCap_func, 0, 0 },
-    { "setLineJoin", (JSNative)setLineJoin_func, 0, 0 },
-    { "setLineWidth", (JSNative)setLineWidth_func, 0, 0 },
+    { "setFontSize", JSOP_WRAPPER((JSNative)setFontSize_func), 0, 0 },
+    { "setFillRule", JSOP_WRAPPER((JSNative)setFillRule_func), 0, 0 },
+    { "setLineCap", JSOP_WRAPPER((JSNative)setLineCap_func), 0, 0 },
+    { "setLineJoin", JSOP_WRAPPER((JSNative)setLineJoin_func), 0, 0 },
+    { "setLineWidth", JSOP_WRAPPER((JSNative)setLineWidth_func), 0, 0 },
     // setMatrix
-    { "setMiterLimit", (JSNative)setMiterLimit_func, 0, 0 },
-    { "setOperator", (JSNative)setOperator_func, 0, 0 },
+    { "setMiterLimit", JSOP_WRAPPER((JSNative)setMiterLimit_func), 0, 0 },
+    { "setOperator", JSOP_WRAPPER((JSNative)setOperator_func), 0, 0 },
     // setScaledFont
-    { "setSource", (JSNative)setSource_func, 0, 0 },
-    { "setSourceRGB", (JSNative)setSourceRGB_func, 0, 0 },
-    { "setSourceRGBA", (JSNative)setSourceRGBA_func, 0, 0 },
-    { "setSourceSurface", (JSNative)setSourceSurface_func, 0, 0 },
-    { "setTolerance", (JSNative)setTolerance_func, 0, 0 },
+    { "setSource", JSOP_WRAPPER((JSNative)setSource_func), 0, 0 },
+    { "setSourceRGB", JSOP_WRAPPER((JSNative)setSourceRGB_func), 0, 0 },
+    { "setSourceRGBA", JSOP_WRAPPER((JSNative)setSourceRGBA_func), 0, 0 },
+    { "setSourceSurface", JSOP_WRAPPER((JSNative)setSourceSurface_func), 0, 0 },
+    { "setTolerance", JSOP_WRAPPER((JSNative)setTolerance_func), 0, 0 },
     // showGlyphs
-    { "showPage", (JSNative)showPage_func, 0, 0 },
-    { "showText", (JSNative)showText_func, 0, 0 },
+    { "showPage", JSOP_WRAPPER((JSNative)showPage_func), 0, 0 },
+    { "showText", JSOP_WRAPPER((JSNative)showText_func), 0, 0 },
     // showTextGlyphs
-    { "stroke", (JSNative)stroke_func, 0, 0 },
-    { "strokeExtents", (JSNative)strokeExtents_func, 0, 0 },
-    { "strokePreserve", (JSNative)strokePreserve_func, 0, 0 },
+    { "stroke", JSOP_WRAPPER((JSNative)stroke_func), 0, 0 },
+    { "strokeExtents", JSOP_WRAPPER((JSNative)strokeExtents_func), 0, 0 },
+    { "strokePreserve", JSOP_WRAPPER((JSNative)strokePreserve_func), 0, 0 },
     // textPath
     // textExtends
     // transform
-    { "translate", (JSNative)translate_func, 0, 0 },
-    { "userToDevice", (JSNative)userToDevice_func, 0, 0 },
-    { "userToDeviceDistance", (JSNative)userToDeviceDistance_func, 0, 0 },
+    { "translate", JSOP_WRAPPER((JSNative)translate_func), 0, 0 },
+    { "userToDevice", JSOP_WRAPPER((JSNative)userToDevice_func), 0, 0 },
+    { "userToDeviceDistance", JSOP_WRAPPER((JSNative)userToDeviceDistance_func), 0, 0 },
     { NULL }
 };
 
