@@ -38,11 +38,11 @@ GJS_DEFINE_PROTO_ABSTRACT("CairoPattern", cairo_pattern)
 GJS_DEFINE_PRIV_FROM_JS(GjsCairoPattern, gjs_cairo_pattern_class)
 
 static void
-gjs_cairo_pattern_finalize(JSContext *context,
-                           JSObject  *obj)
+gjs_cairo_pattern_finalize(JSFreeOp *fop,
+                           JSObject *obj)
 {
     GjsCairoPattern *priv;
-    priv = JS_GetPrivate(context, obj);
+    priv = JS_GetPrivate(obj);
     if (priv == NULL)
         return;
     cairo_pattern_destroy(priv->pattern);
@@ -82,7 +82,7 @@ getType_func(JSContext *context,
 
 static JSFunctionSpec gjs_cairo_pattern_proto_funcs[] = {
     // getMatrix
-    { "getType", (JSNative)getType_func, 0, 0 },
+    { "getType", JSOP_WRAPPER((JSNative)getType_func), 0, 0 },
     // setMatrix
     { NULL }
 };
@@ -114,7 +114,7 @@ gjs_cairo_pattern_construct(JSContext       *context,
     priv = g_slice_new0(GjsCairoPattern);
 
     g_assert(priv_from_js(context, object) == NULL);
-    JS_SetPrivate(context, object, priv);
+    JS_SetPrivate(object, priv);
 
     priv->context = context;
     priv->object = object;
@@ -123,7 +123,7 @@ gjs_cairo_pattern_construct(JSContext       *context,
 
 /**
  * gjs_cairo_pattern_finalize:
- * @context: the context
+ * @fop: the free op
  * @object: object to finalize
  *
  * Destroys the resources associated with a pattern wrapper.
@@ -132,13 +132,13 @@ gjs_cairo_pattern_construct(JSContext       *context,
  */
 
 void
-gjs_cairo_pattern_finalize_pattern(JSContext *context,
-                                   JSObject  *object)
+gjs_cairo_pattern_finalize_pattern(JSFreeOp *fop,
+                                   JSObject *object)
 {
-    g_return_if_fail(context != NULL);
+    g_return_if_fail(fop != NULL);
     g_return_if_fail(object != NULL);
 
-    gjs_cairo_pattern_finalize(context, object);
+    gjs_cairo_pattern_finalize(fop, object);
 }
 
 /**
@@ -154,8 +154,6 @@ JSObject *
 gjs_cairo_pattern_from_pattern(JSContext       *context,
                                cairo_pattern_t *pattern)
 {
-    JSObject *object;
-
     g_return_val_if_fail(context != NULL, NULL);
     g_return_val_if_fail(pattern != NULL, NULL);
 
@@ -175,8 +173,6 @@ gjs_cairo_pattern_from_pattern(JSContext       *context,
     gjs_throw(context, "failed to create pattern, unsupported pattern type %d",
               cairo_pattern_get_type(pattern));
     return NULL;
-
-    return object;
 }
 
 /**
@@ -196,7 +192,7 @@ gjs_cairo_pattern_get_pattern(JSContext *context,
     g_return_val_if_fail(context != NULL, NULL);
     g_return_val_if_fail(object != NULL, NULL);
 
-    priv = JS_GetPrivate(context, object);
+    priv = JS_GetPrivate(object);
     if (priv == NULL)
         return NULL;
 
