@@ -24,6 +24,7 @@
 
 #include <gjs/gjs-module.h>
 #include <gjs/compat.h>
+#include <gi/foreign.h>
 #include <cairo.h>
 #include "cairo-private.h"
 
@@ -38,11 +39,11 @@ GJS_DEFINE_PROTO_ABSTRACT("CairoSurface", cairo_surface)
 GJS_DEFINE_PRIV_FROM_JS(GjsCairoSurface, gjs_cairo_surface_class)
 
 static void
-gjs_cairo_surface_finalize(JSContext *context,
-                           JSObject  *obj)
+gjs_cairo_surface_finalize(JSFreeOp *fop,
+                           JSObject *obj)
 {
     GjsCairoSurface *priv;
-    priv = JS_GetPrivate(context, obj);
+    priv = JS_GetPrivate(obj);
     if (priv == NULL)
         return;
     cairo_surface_destroy(priv->surface);
@@ -111,7 +112,7 @@ static JSFunctionSpec gjs_cairo_surface_proto_funcs[] = {
     // flush
     // getContent
     // getFontOptions
-    { "getType", (JSNative)getType_func, 0, 0},
+    { "getType", JSOP_WRAPPER((JSNative)getType_func), 0, 0},
     // markDirty
     // markDirtyRectangle
     // setDeviceOffset
@@ -121,7 +122,7 @@ static JSFunctionSpec gjs_cairo_surface_proto_funcs[] = {
     // copyPage
     // showPage
     // hasShowTextGlyphs
-    { "writeToPNG", (JSNative)writeToPNG_func, 0, 0 },
+    { "writeToPNG", JSOP_WRAPPER((JSNative)writeToPNG_func), 0, 0 },
     { NULL }
 };
 
@@ -152,7 +153,7 @@ gjs_cairo_surface_construct(JSContext       *context,
     priv = g_slice_new0(GjsCairoSurface);
 
     g_assert(priv_from_js(context, object) == NULL);
-    JS_SetPrivate(context, object, priv);
+    JS_SetPrivate(object, priv);
 
     priv->context = context;
     priv->object = object;
@@ -161,7 +162,7 @@ gjs_cairo_surface_construct(JSContext       *context,
 
 /**
  * gjs_cairo_surface_finalize:
- * @context: the context
+ * @fop: the free op
  * @object: object to finalize
  *
  * Destroys the resources associated with a surface wrapper.
@@ -169,13 +170,13 @@ gjs_cairo_surface_construct(JSContext       *context,
  * This is mainly used for subclasses.
  */
 void
-gjs_cairo_surface_finalize_surface(JSContext *context,
-                                   JSObject  *object)
+gjs_cairo_surface_finalize_surface(JSFreeOp *fop,
+                                   JSObject *object)
 {
-    g_return_if_fail(context != NULL);
+    g_return_if_fail(fop != NULL);
     g_return_if_fail(object != NULL);
 
-    gjs_cairo_surface_finalize(context, object);
+    gjs_cairo_surface_finalize(fop, object);
 }
 
 /**
@@ -237,9 +238,67 @@ gjs_cairo_surface_get_surface(JSContext *context,
     g_return_val_if_fail(context != NULL, NULL);
     g_return_val_if_fail(object != NULL, NULL);
 
-    priv = JS_GetPrivate(context, object);
+    priv = JS_GetPrivate(object);
     if (priv == NULL)
         return NULL;
     return priv->surface;
 }
 
+static JSBool
+surface_to_g_argument(JSContext      *context,
+                      jsval           value,
+                      const char     *arg_name,
+                      GjsArgumentType argument_type,
+                      GITransfer      transfer,
+                      gboolean        may_be_null,
+                      GArgument      *arg)
+{
+    JSObject *obj;
+    cairo_surface_t *s;
+
+    obj = JSVAL_TO_OBJECT(value);
+    s = gjs_cairo_surface_get_surface(context, obj);
+    if (!s)
+        return JS_FALSE;
+    if (transfer == GI_TRANSFER_EVERYTHING)
+        cairo_surface_destroy(s);
+
+    arg->v_pointer = s;
+    return JS_TRUE;
+}
+
+static JSBool
+surface_from_g_argument(JSContext  *context,
+                        jsval      *value_p,
+                        GArgument  *arg)
+{
+    JSObject *obj;
+
+    obj = gjs_cairo_surface_from_surface(context, (cairo_surface_t*)arg->v_pointer);
+    if (!obj)
+        return JS_FALSE;
+
+    *value_p = OBJECT_TO_JSVAL(obj);
+    return JS_TRUE;
+}
+
+static JSBool
+surface_release_argument(JSContext  *context,
+                         GITransfer  transfer,
+                         GArgument  *arg)
+{
+    cairo_surface_destroy((cairo_surface_t*)arg->v_pointer);
+    return JS_TRUE;
+}
+
+static GjsForeignInfo foreign_info = {
+    surface_to_g_argument,
+    surface_from_g_argument,
+    surface_release_argument
+};
+
+void
+gjs_cairo_surface_init(JSContext *context)
+{
+    gjs_struct_foreign_register("cairo", "Surface", &foreign_info);
+}
